/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.gnome;

import org.gnu.glib.Type;
import org.gnu.gtk.Dialog;
import org.gnu.javagnome.Handle;

/**
 * The GnomeScores widget displays a list of names and scores for the
 * players of a game.
 * 
 * @deprecated
 */
public class Scores extends Dialog {
	/**
	 * Retrieve the runtime type used by the GLib library.
	 */
	public static Type getType() {
		return new Type(gnome_scores_get_type());
	}
	

	native static final protected int gnome_scores_get_type();
	native static final protected Handle gnome_scores_display(String title, String app_name, String level, int pos);
	native static final protected void gnome_scores_set_logo_pixmap(Handle gs, String logo);
	native static final protected void gnome_scores_set_logo_widget(Handle gs, int widget);
	native static final protected void gnome_scores_set_logo_label_title(Handle gs, String title);
	native static final protected void gnome_scores_set_current_player(Handle gs, int i);

}
